.. meta::
   :description: Gaitalytics Extensions.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, guide, extend

Extend Functionality
====================
Gaitalytics is build to be extensible and flexible. You can extend the functionality of the framework by adding new features or new event detection algorithms.
In the following pages, we will explain how you can extend the functionality of Gaitalytics for your specific needs.
Additionally, you can also make your extensions available to the community by :ref:`contributing <Development>` to the project.

.. toctree::
   :maxdepth: 2
   :hidden:

   features

..





